"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var utils_1 = require("./utils");
var messagebox_component_1 = require("./messagebox.component");
var BaseComponent = /** @class */ (function () {
    function BaseComponent() {
        this.calLang = calLang;
    }
    /**
     * 解析国际化消息
     * @param key 键
     * @param params 参数
     */
    BaseComponent.prototype.resolveMessage = function (key) {
        var params = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            params[_i - 1] = arguments[_i];
        }
        return utils_1.Utils.resolveLocalizedMessage(key, params);
    };
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    BaseComponent.prototype.lookup = function (key, dictMap, defaultKey) {
        if (defaultKey === void 0) { defaultKey = "-"; }
        return utils_1.Utils.lookup(key, dictMap, defaultKey);
    };
    /**
     * 处理错误
     * @param error 错误对象
     */
    BaseComponent.prototype.handleError = function (error, mBox) {
        if (mBox === void 0) { mBox = this.messageBox; }
        if (this && this.messageBox) {
            this.messageBox.showMessage("error", error);
        }
        else if (mBox) {
            mBox.showMessage("error", error);
        }
        else {
            alert(error);
        }
    };
    /**
     * 显示错误消息
     * @param message 消息
     */
    BaseComponent.prototype.showError = function (message) {
        this.showMessage(message, "error");
    };
    /**
     * i18n的显示警告消息
     * @param messageKey 要显示的消息key
     */
    BaseComponent.prototype.showWarnKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "warn");
    };
    /**
     * i18n的显示成功消息
     * @param messageKey 要显示的消息key
     */
    BaseComponent.prototype.showSuccessKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "success");
    };
    /**
     * 	i18n的显示通知消息
     * @param messageKey 要显示的消息key
     */
    BaseComponent.prototype.showInfoKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "info");
    };
    /**
     * 	i18n的显示错误消息
     * @param messageKey 要显示的消息key
     */
    BaseComponent.prototype.showErrorKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "error");
    };
    /**
     * 显示消息
     * @param message 要显示的消息
     * @param style 消息风格，"warn","success","info","error"
     */
    BaseComponent.prototype.showMessage = function (message, style) {
        if (this && this.messageBox) {
            this.messageBox.showMessage(style, message);
        }
        else {
            alert(message);
        }
    };
    /**
     * 获取请求串中的参数值
     * @param name 参数名称
     *
     */
    BaseComponent.prototype.getRequestParamValue = function (name) {
        var result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
        if (result == null || result.length < 1) {
            return null;
        }
        return result[1];
    };
    /**
     * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
     * @param name 参数名称
     */
    BaseComponent.prototype.getRequestParamValues = function (name) {
        var result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
        if (result == null || result.length < 1) {
            return null;
        }
        return result;
    };
    /**
     * 判断是否有异步任务正在执行，以便界面显示相关信息，让用户等待
     */
    BaseComponent.prototype.isRunning = function () {
        return isRunning > 0;
    };
    BaseComponent.MSG_SAVED_KEY = "msg.saved.success";
    BaseComponent.MSG_DELETED_KEY = "msg.deleted.success";
    __decorate([
        core_1.ViewChild(messagebox_component_1.MessageBoxComponent),
        __metadata("design:type", messagebox_component_1.MessageBoxComponent)
    ], BaseComponent.prototype, "messageBox", void 0);
    return BaseComponent;
}());
exports.BaseComponent = BaseComponent;
//# sourceMappingURL=base.component.js.map