import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Observable } from 'rxjs';
import { PagedQueryResult, PagedQueryParam } from './models';
export declare abstract class BaseService {
    private http;
    protected headers: HttpHeaders;
    constructor(http: HttpClient);
    /**
     * 分页查询
     * 参数：url URL地址, queryParam：用于查询的参数。waitLoading: 是否要显示等待加载（缺省true）
     */
    protected searchPage(url: string, queryParam: PagedQueryParam, waitLoading?: boolean): Observable<PagedQueryResult<any>>;
    /**
     * 把输入的Object转换成请求参数串。
     * 如 obj = {a:1, b:[{i:3, k:4},{i:5}]，则返回的请求串为：
     * "&a=1&b[0].i=3&b[0].k=4&b[1].i=6"
     *
     */
    toQueryString(obj: any, propPrefix: string): string;
    private formatValue;
    /**
     * GET请求
     * @param url URL地址
     * @param data：用于查询的参数
     * @param waitLoading: 是否要显示等待加载（缺省true）
     */
    protected doGet(url: string, data?: any, waitLoading?: boolean): Observable<any>;
    /**
     * PUT请求
     * @param url URL地址,
     * @param data：发送到服务器的数据
     * @param waitLoading: 是否要显示等待加载（缺省true）
     */
    protected doPut(url: string, data: any, waitLoading?: boolean): Observable<any>;
    /**
     * POST请求
     * @param url URL地址
     * @param data：要post的数据
     * @param waitLoading: 是否要显示等待加载（缺省true）
     *
     */
    protected doPost(url: string, data: any, waitLoading?: boolean): Observable<any>;
    /**
     * DELETE请求
     * @param url URL地址,
     * @param waitLoading: 是否要显示等待加载（缺省true）
     */
    protected doDelete(url: string, waitLoading?: boolean): Observable<any>;
    protected processResponse(response: any, waitLoading: boolean): any;
    protected processDate(rst: any): any;
    protected handleError(error: any, waitLoading: boolean): Observable<any>;
}
