import { MessageService } from 'primeng/api';
export declare abstract class BaseSubComponent {
    private messageService;
    calLang: any;
    constructor(messageService: MessageService);
    /**
     * 解析国际化消息
     * @param key 键
     * @param params 参数
     */
    resolveMessage(key: string, ...params: string[]): string;
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    lookup(key: any, dictMap: Object, defaultKey?: string): string;
    /**
     * 处理错误
     * @param error 错误对象
     */
    protected handleError(error: any): void;
    /**
     * 显示错误消息
     * @param message 消息
     */
    protected showError(message: string): void;
    /**
     * i18n的显示警告消息
     * @param messageKey 要显示的消息key
     */
    protected showWarnKey(messageKey: string): void;
    /**
     * i18n的显示成功消息
     * @param messageKey 要显示的消息key
     */
    protected showSuccessKey(messageKey: string): void;
    /**
     * 	i18n的显示通知消息
     * @param messageKey 要显示的消息key
     */
    protected showInfoKey(messageKey: string): void;
    /**
     * 	i18n的显示错误消息
     * @param messageKey 要显示的消息key
     */
    protected showErrorKey(messageKey: string): void;
    /**
     * 显示消息
     * @param message 要显示的消息
     * @param style 消息风格，"warn","success","info","error"
     */
    protected showMessage(message: string, style?: string): void;
    /**
     * 获取请求串中的参数值
     * @param name 参数名称
     *
     */
    protected getRequestParamValue(name: string): string;
    /**
     * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
     * @param name 参数名称
     */
    protected getRequestParamValues(name: string): string[];
}
