"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
var BaseSubComponent = /** @class */ (function () {
    function BaseSubComponent(messageService) {
        this.messageService = messageService;
        this.calLang = calLang;
    }
    /**
     * 解析国际化消息
     * @param key 键
     * @param params 参数
     */
    BaseSubComponent.prototype.resolveMessage = function (key) {
        var params = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            params[_i - 1] = arguments[_i];
        }
        return utils_1.Utils.resolveLocalizedMessage(key, params);
    };
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    BaseSubComponent.prototype.lookup = function (key, dictMap, defaultKey) {
        if (defaultKey === void 0) { defaultKey = "-"; }
        return utils_1.Utils.lookup(key, dictMap, defaultKey);
    };
    /**
     * 处理错误
     * @param error 错误对象
     */
    BaseSubComponent.prototype.handleError = function (error) {
        this.showMessage(error, "error");
    };
    /**
     * 显示错误消息
     * @param message 消息
     */
    BaseSubComponent.prototype.showError = function (message) {
        this.showMessage(message, "error");
    };
    /**
     * i18n的显示警告消息
     * @param messageKey 要显示的消息key
     */
    BaseSubComponent.prototype.showWarnKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "warn");
    };
    /**
     * i18n的显示成功消息
     * @param messageKey 要显示的消息key
     */
    BaseSubComponent.prototype.showSuccessKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "success");
    };
    /**
     * 	i18n的显示通知消息
     * @param messageKey 要显示的消息key
     */
    BaseSubComponent.prototype.showInfoKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "info");
    };
    /**
     * 	i18n的显示错误消息
     * @param messageKey 要显示的消息key
     */
    BaseSubComponent.prototype.showErrorKey = function (messageKey) {
        this.showMessage(this.resolveMessage(messageKey), "error");
    };
    /**
     * 显示消息
     * @param message 要显示的消息
     * @param style 消息风格，"warn","success","info","error"
     */
    BaseSubComponent.prototype.showMessage = function (message, style) {
        if (!style) {
            style = "info";
        }
        var title = utils_1.Utils.resolveLocalizedMessage("msg.type." + style);
        this.messageService.add({ severity: style, summary: title, detail: message });
    };
    /**
     * 获取请求串中的参数值
     * @param name 参数名称
     *
     */
    BaseSubComponent.prototype.getRequestParamValue = function (name) {
        var result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
        if (result == null || result.length < 1) {
            return null;
        }
        return result[1];
    };
    /**
     * 获取请求串中的参数值数组，如a=x&a=y, 则参数a的值为['x','y']
     * @param name 参数名称
     */
    BaseSubComponent.prototype.getRequestParamValues = function (name) {
        var result = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
        if (result == null || result.length < 1) {
            return null;
        }
        return result;
    };
    return BaseSubComponent;
}());
exports.BaseSubComponent = BaseSubComponent;
//# sourceMappingURL=base.sub.component.js.map