import { Selectable } from './models';
export declare class Utils {
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean，如果是RefBean，则以code为键。
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    static lookup(key: any, dictMap: Object, defaultKey?: string): string;
    /**
     * 把Error Object中的错误消息解析出友好的消息
     * @param err Error Object
     * @return 友好的消息
     */
    static resolveJsonErrorMessage(err: any): string;
    static showMessage(msg: string): void;
    static showMessageByKey(key: string): void;
    static cloneObject(src: Object, dist: Object): void;
    /**根据key和参数，找到相应的语言标签
     * @param key the message key
     * @param params parameters to replace the placeholder in message. If params is not an array, then treat it as the first parameter.
     * @return resolved localized message. return the key if message not found.
     */
    static resolveLocalizedMessage(key: string, params?: string[]): string;
    /** 对比两个数组的内容是否一样.
     * @param array1 数组1
     * @param array2 数组2
     * @param property 要比较的属性值
     * @return true if same.
     */
    static compareArrays(array1: Array<any>, array2: Array<any>, property: string): boolean;
    /**
     * 取得当前数据日期
    */
    static getCurrentDataDate(): string;
    /**
     * 取得当前的一级机构号
    */
    static getCurrentNodeCode(): string;
    /**
     * 取得指定的cookie变量值
    */
    static getCookie(name: string): any;
    /**
     * 取得当前域名，如: baidu.com
    */
    static getDomainName(): string;
    /**
     * 设置指定的cookie变量值
    */
    static setCookie1(name: string, value: string, path?: string, domain?: string, expries?: Date): void;
    /**
     * 设置指定的cookie变量值以及有效时间（毫秒）
    */
    static setCookie(name: string, value: string, msec?: number): void;
    /**
     * 删除指定的cookie变量
    */
    static delCookie(name: string): void;
    /**
     * 获取可选取列表中选中的项目
     * @param array 可选项目列表
     * @param property 返回的选中项目属性，如列表是TreeNode类型，而要返回的选中项可能是TreeNode.data,那么porperty就应该是“data”，如果不提供porperty，将返回列表中选中的TreeNode。
    */
    static getSelectedBeans(array: Selectable[], property?: string): any[];
    /**
     * 格式化数字显示方式
     * 用法
     * formatNumber(12345.999,'#,##0.00');
     * formatNumber(12345.999,'#,##0.##');
     * formatNumber(123,'000000');
     * @param num  要格式化的数字
     * @param pattern  想要的格式
     */
    static formatNumber(num: number, pattern: string): string;
    /**
     * 将日期串转换成日期类型的变量
     * @param dateStr 日期串，支持如2018-10-31, 20181031, 31/10/2018等格式
     *
     */
    static parseDate(dateStr: string): Date;
    /**
     * 将日期按照指定的格式格式化成字符串用于显示
     * @param date 日期
     * @param fmt 想要的格式，如：“yyyy-MM-dd hh:mm:ss S”, “yyyy年第q季度”
     */
    static formatDate(date: Date, fmt: string): string;
    /**
     * 获取请求参数的值，如var=1，则返回"1"
     * @param name 参数名
     */
    static getParameter(name: string): string;
    /**
     * 获取同名多个请求参数的值数组，如var=1&var=2,返回["1","2"]
     * @param name 参数名
     */
    static getParameterValues(name: string): string[];
}
