"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Utils = /** @class */ (function () {
    function Utils() {
    }
    /**
     *  把代码映射成字典表中的i18n值，如果代码为空，则返回代码为defaultKey的值，如果连defaultKey也找不到值，则返回代码本身，如果 代码为null或undefined则返回空串。
     * @param key 要映射的代码,或是RefBean，如果是RefBean，则以code为键。
     * @param dictMap 字典数据
     * @param defaultKey 缺省代码，可选参数，缺省为"-"
     */
    Utils.lookup = function (key, dictMap, defaultKey) {
        if (defaultKey === void 0) { defaultKey = "-"; }
        var _key = key;
        if (key && key.code) {
            _key = key.code;
        }
        if (!_key) {
            _key = defaultKey;
        }
        if (dictMap) {
            var _val = dictMap[_key];
            if (_val) {
                return _val;
            }
        }
        if (key && key.name) {
            return key.name;
        }
        return _key;
    };
    /**
     * 把Error Object中的错误消息解析出友好的消息
     * @param err Error Object
     * @return 友好的消息
     */
    Utils.resolveJsonErrorMessage = function (err) {
        var rn = "。";
        /* Spring MVC Sample:
         * 1.
         * {
         * "headers":{"normalizedNames":{},"lazyUpdate":null},
         * "status":500,
         * "statusText":"OK",
         * "url":"http://localhost:8080/aiib-irmp-web/rest/iisp-job/job-items",
         * "ok":false,
         * "name":"HttpErrorResponse",
         * "message":"Http failure response for http://localhost:8080/aiib-irmp-web/rest/iisp-job/job-items: 500 OK",
         * "error":{"type":"RuntimeException","message":"Error occurred here."}}
         * 2.
         * {headers: HttpHeaders, status: 500, statusText: "Internal Server Error",
            url: "http://localhost:8080/cgd-web/rest/iisp-access-log/logs?x=1&pageNumber=1&pageSize=20",
            ok: false,
            "error":{"messageKey":"err.IISP_AUTH_ROLE_003","code":"IISP_AUTH_ROLE_003","localizedMessage":"要删除的角色不存在!","type":"I18nAppException","message":"Role not exists."}}"
            error: {code: "IISP_AUTH_ROLE_003"
                defaultMessage: "Default"
                localizedMessage: "要删除的角色不存在!"
                messageKey: "err.IISP_AUTH_ROLE_003"
                type: "I18nAppException"}
        }
        3."{"headers":{"normalizedNames":{},"lazyUpdate":null},
        "status":503,
        "statusText":"Service Unavailable",
        "url":"http://localhost/ibm-graph-web/rest/iisp-base/dict/map/IISP_JOB_TYPE","ok":false,
        "name":"HttpErrorResponse",
        "message":"Http failure response for http://localhost/ibm-graph-web/rest/iisp-base/dict/map/IISP_JOB_TYPE: 503 Service Unavailable","error":"<!DOCTYPE HTML PUBLIC \"-//IETF//DTD HTML 2.0//EN\">\n<html><head>\n<title>503 Service Unavailable</title>\n</head><body>\n<h1>Service Unavailable</h1>\n<p>The server is temporarily unable to service your\nrequest due to maintenance downtime or capacity\nproblems. Please try again later.</p>\n</body></html>\n"}"
        */
        var msg = Utils.resolveLocalizedMessage("msg.errorOccurred");
        if (err.error && err.error.defaultMessage) {
            err = err.error;
            if (err.defaultMessage) {
                if (err.code) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorCode") + "：" + err.code;
                }
                if (err.localizedMessage) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.localizedMessage;
                }
                else {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.defaultMessage;
                }
                if (err.cause) {
                    msg = msg + rn + Utils.resolveLocalizedMessage("msg.rootMessage") + "：" + err.cause;
                }
                //Utils.showMessage(msg);
                return msg;
            }
        }
        if (err.localizedMessage) {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.localizedMessage;
        }
        else if (err.message) {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err.message;
        }
        else {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.errorMessage") + "：" + err;
        }
        if (err.status) {
            msg = msg + rn + Utils.resolveLocalizedMessage("msg.httpStatus") + err.status;
            //msg = msg + rn + Utils.resolveLocalizedMessage("msg.returnMessage") + err.statusText;
        }
        return msg;
    };
    Utils.showMessage = function (msg) {
        alert(msg);
    };
    Utils.showMessageByKey = function (key) {
        Utils.showMessage(Utils.resolveLocalizedMessage(key));
    };
    Utils.cloneObject = function (src, dist) {
        for (var prop in src) {
            dist[prop] = src[prop];
        }
    };
    /**根据key和参数，找到相应的语言标签
     * @param key the message key
     * @param params parameters to replace the placeholder in message. If params is not an array, then treat it as the first parameter.
     * @return resolved localized message. return the key if message not found.
     */
    Utils.resolveLocalizedMessage = function (key, params) {
        var msg = langMap[key];
        if (msg == undefined) {
            return key;
        }
        if (params) {
            if (params.length) {
                for (var i = 0; i < params.length; i++) {
                    msg = msg.replace("{" + i + "}", params[i]);
                }
            }
            else {
                msg = msg.replace("{0}", params);
            }
        }
        return msg;
    };
    /** 对比两个数组的内容是否一样.
     * @param array1 数组1
     * @param array2 数组2
     * @param property 要比较的属性值
     * @return true if same.
     */
    Utils.compareArrays = function (array1, array2, property) {
        if (array1.length != array2.length) {
            return false;
        }
        for (var i = 0; i < array1.length; i++) {
            var obj1 = array1[i];
            var found = false;
            for (var k = 0; k < array2.length; k++) {
                var obj2 = array2[k];
                if (property) {
                    if (obj2[property] == obj1[property]) {
                        found = true;
                        break;
                    }
                }
                else {
                    if (obj2 == obj1) {
                        found = true;
                        break;
                    }
                }
            }
            if (!found) {
                return false;
            }
        }
        return true;
    };
    /**
     * 取得当前数据日期
    */
    Utils.getCurrentDataDate = function () {
        return Utils.getCookie("currentDataDate");
    };
    /**
     * 取得当前的一级机构号
    */
    Utils.getCurrentNodeCode = function () {
        return Utils.getCookie("currentNodeCode");
    };
    /**
     * 取得指定的cookie变量值
    */
    Utils.getCookie = function (name) {
        var arr, reg = new RegExp("(^| )" + name + "=([^;]*)(;|$)"); //正则匹配
        if (arr = document.cookie.match(reg)) {
            return unescape(arr[2]);
        }
        else {
            return null;
        }
    };
    /**
     * 取得当前域名，如: baidu.com
    */
    Utils.getDomainName = function () {
        var names = document.domain.split('.');
        if (names.length > 1) {
            var dname = names[1];
            for (var i = 2; i < names.length; i++) {
                dname += '.' + names[i];
            }
            return dname;
        }
        return document.domain;
    };
    /**
     * 设置指定的cookie变量值
    */
    Utils.setCookie1 = function (name, value, path, domain, expries) {
        var cookieName = name + "=" + escape(value);
        if (expries) {
            cookieName += ";expries=" + expries;
        }
        if (path) {
            cookieName += ";path=" + path;
        }
        if (domain) {
            cookieName += ";domain=" + domain;
        }
        document.cookie = cookieName;
    };
    /**
     * 设置指定的cookie变量值以及有效时间（毫秒）
    */
    Utils.setCookie = function (name, value, msec) {
        var cs = name + '=' + escape(value);
        if (msec) {
            var exp = new Date();
            exp.setTime(exp.getTime() + msec * 1);
            cs += ";expires=" + exp.toUTCString();
        }
        document.cookie = cs;
    };
    /**
     * 删除指定的cookie变量
    */
    Utils.delCookie = function (name) {
        var exp = new Date();
        exp.setTime(exp.getTime() - 1);
        var cval = Utils.getCookie(name);
        if (cval != null) {
            document.cookie = name + "=" + cval + ";expires=" + exp.toUTCString();
        }
    };
    /**
     * 获取可选取列表中选中的项目
     * @param array 可选项目列表
     * @param property 返回的选中项目属性，如列表是TreeNode类型，而要返回的选中项可能是TreeNode.data,那么porperty就应该是“data”，如果不提供porperty，将返回列表中选中的TreeNode。
    */
    Utils.getSelectedBeans = function (array, property) {
        var rst = new Array();
        for (var _i = 0, array_1 = array; _i < array_1.length; _i++) {
            var s = array_1[_i];
            if (s.isSelected) {
                if (property) {
                    rst.push(s[property]);
                }
                else {
                    rst.push(s);
                }
            }
        }
        return rst;
    };
    /**
     * 格式化数字显示方式
     * 用法
     * formatNumber(12345.999,'#,##0.00');
     * formatNumber(12345.999,'#,##0.##');
     * formatNumber(123,'000000');
     * @param num  要格式化的数字
     * @param pattern  想要的格式
     */
    Utils.formatNumber = function (num, pattern) {
        var strarr = num ? num.toString().split('.') : ['0'];
        var fmtarr = pattern ? pattern.split('.') : [''];
        var retstr = '';
        // 整数部分   
        var str = strarr[0];
        var fmt = fmtarr[0];
        var i = str.length - 1;
        var comma = false;
        for (var f = fmt.length - 1; f >= 0; f--) {
            switch (fmt.substr(f, 1)) {
                case '#':
                    if (i >= 0)
                        retstr = str.substr(i--, 1) + retstr;
                    break;
                case '0':
                    if (i >= 0)
                        retstr = str.substr(i--, 1) + retstr;
                    else
                        retstr = '0' + retstr;
                    break;
                case ',':
                    comma = true;
                    retstr = ',' + retstr;
                    break;
            }
        }
        if (i >= 0) {
            if (comma) {
                var l = str.length;
                for (; i >= 0; i--) {
                    retstr = str.substr(i, 1) + retstr;
                    if (i > 0 && ((l - i) % 3) == 0)
                        retstr = ',' + retstr;
                }
            }
            else
                retstr = str.substr(0, i + 1) + retstr;
        }
        retstr = retstr + '.';
        // 处理小数部分   
        str = strarr.length > 1 ? strarr[1] : '';
        fmt = fmtarr.length > 1 ? fmtarr[1] : '';
        i = 0;
        for (var f = 0; f < fmt.length; f++) {
            switch (fmt.substr(f, 1)) {
                case '#':
                    if (i < str.length)
                        retstr += str.substr(i++, 1);
                    break;
                case '0':
                    if (i < str.length)
                        retstr += str.substr(i++, 1);
                    else
                        retstr += '0';
                    break;
            }
        }
        return retstr.replace(/^,+/, '').replace(/\.$/, '');
    };
    /**
     * 将日期串转换成日期类型的变量
     * @param dateStr 日期串，支持如2018-10-31, 20181031, 31/10/2018等格式
     *
     */
    Utils.parseDate = function (dateStr) {
        if (dateStr.length == 8) {
            //yyyyMMdd格式
            var year = parseInt(dateStr.substr(0, 4));
            var month = parseInt(dateStr.substr(4, 2));
            var day = parseInt(dateStr.substr(6, 2));
            return new Date(year, month - 1, day);
        }
        //其它格式
        return new Date(dateStr);
    };
    /**
     * 将日期按照指定的格式格式化成字符串用于显示
     * @param date 日期
     * @param fmt 想要的格式，如：“yyyy-MM-dd hh:mm:ss S”, “yyyy年第q季度”
     */
    Utils.formatDate = function (date, fmt) {
        var o = {
            "M+": date.getMonth() + 1,
            "d+": date.getDate(),
            "h+": date.getHours(),
            "m+": date.getMinutes(),
            "s+": date.getSeconds(),
            "q+": Math.floor((date.getMonth() + 3) / 3),
            "S": date.getMilliseconds() //毫秒   
        };
        if (/(y+)/.test(fmt))
            fmt = fmt.replace(RegExp.$1, (date.getFullYear() + "").substr(4 - RegExp.$1.length));
        for (var k in o)
            if (new RegExp("(" + k + ")").test(fmt))
                fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
        return fmt;
    };
    /**
     * 获取请求参数的值，如var=1，则返回"1"
     * @param name 参数名
     */
    Utils.getParameter = function (name) {
        var val = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "i"));
        if (val && val.length > 0) {
            return decodeURI(val[1]);
        }
        return null;
    };
    ;
    /**
     * 获取同名多个请求参数的值数组，如var=1&var=2,返回["1","2"]
     * @param name 参数名
     */
    Utils.getParameterValues = function (name) {
        var rsts = location.search.match(new RegExp("[\?\&]" + name + "=([^\&]+)", "g"));
        if (rsts && rsts.length > 0) {
            var vals = new Array(rsts.length);
            for (var i = 0; i < rsts.length; i++) {
                vals[i] = decodeURI(rsts[i].substring(rsts[i].indexOf("=") + 1));
            }
            return vals;
        }
        return null;
    };
    ;
    return Utils;
}());
exports.Utils = Utils;
//# sourceMappingURL=utils.js.map