import { Component, Input } from "@angular/core";
import { Utils } from './utils';

declare var fileDownloadRoot: string;
@Component( {
    moduleId: module.id,
    selector: "iisp-file-download",
    template: `
    <a href="{{resolveDownloadUrl(fileUri)}}" target="_blank"><span class="filedownload"><i class="fa fa-{{getFileIcon()}}"></i>{{getLabel()}}</span></a>
    `
} )
export class FileDownloadComponent{
    @Input() fileUri: string;
    @Input() labelKey: string;
    fileDownloadRoot = fileDownloadRoot;
    fileTypes ={
        image: [".png",".jpg",".jpeg",".bmp",".gif"],//图片文件的后缀名
        word: [".doc",".docx"],//word文件的后缀名
        excel: [".xls",".xlsx"],//excel文件的后缀名
        powerpoint: [".ppt", ".pptx"],
        audio: [".wav", ".mp3", ".ogg", ".flac", ".ape"],
        video: [".mov", ".mp4", ".avi", ".asf", ".rm", ".rmvb", ".mpeg"],
        pdf: [".pdf"],//pdf文件的后缀名
        text: [".txt", ".csv", ".xml", ".text", ".tsv"],
        achive: [".zip",".gz",".tar",".7z",".rar",".jar", ".war", ".ear", ".tgz"],//pdf文件的后缀名
        code: [".js", ".ts",".java",".c", ".sql", ".htm", ".html", , ".css"]//代码的后缀名
    }
    getLabel():string{
        if (this.labelKey) {
            return Utils.resolveLocalizedMessage(this.labelKey);
        }
        return ""
    }
    getFileExt(): string {
        let i = this.fileUri.lastIndexOf(".");
        if(i > -1){
            return this.fileUri.substring(i);
        }
        return null;
    }
    getFileIcon():string {
        let fe = this.getFileExt();
        if (fe) {
            for (let ftypes in this.fileTypes) {
                for (let ft of this.fileTypes[ftypes]) {
                    if (ft == fe) {
                        return 'file-' + ftypes + '-o';
                    }
                }
            }
        }
        return "file";
    }
        /**
     * 生成下载链接。
     * @param uri 附件的相对路径
     */
    resolveDownloadUrl(uri: string): string {
        return fileDownloadRoot + encodeURI(uri);
    }
}