import { Component, Input } from "@angular/core";
import { BaseComponent } from './base.component';

declare var restRoot: string;;
@Component( {
    moduleId: module.id,
    selector: "iisp-file-upload",
    template: `
    <div style="display:inline-block;">
    <p-fileUpload mode="basic" [multiple]="fileUploadInfo.isMultipleMode" [url]="uploadUrl" [accept]="fileUploadInfo.allowedFileType"
        [disabled]="fileUploadInfo.isDisabled" [auto]="fileUploadInfo.isAutoUpload" 
        uploadLabel="{{'upload.file'|i18n}}" cancelLabel="{{'upload.cancel'|i18n}}" chooseLabel="{{'choose.file'|i18n}}"
        maxFileSize="{{fileUploadInfo.maxSize}}" (onUpload)="onUpload($event)" (onError)="onError($event)" (onClear)="onClear()" (onProgress)="onProgress()">
    </p-fileUpload>
    </div>
    <div style="display:inline-block;">
        <i *ngIf="isUploading" class="ui-autocomplete-loader fa fa-circle-o-notch fa-spin fa-fw ng-star-inserted" style="position: static;"></i>
        <span *ngIf="fileUploadInfo.files"><ul><li *ngFor='let f1 of fileUploadInfo.files'>{{f1.name}} - {{f1.size/1000 | number: '1.0-0'}}KB</li></ul></span>
    </div>
    `
} )
export class FileUploadComponent extends BaseComponent {
    @Input()
    fileUploadInfo: FileUploadInfo;
    files: Array<any>;
    uploadUrl = restRoot + "/common/files";
    isUploading = false;
    //  定义事件，上传文件
    onUpload( event: any) {
        this.fileUploadInfo.uploadedFiles = JSON.parse( event.xhr.response ).uploadPaths;
        this.fileUploadInfo['files'] = new Array();
        for ( let file of event.files ) {
            this.fileUploadInfo['files'].push( file );
        }
    }
    onError( event: any) {
        this.showErrorKey("upload.file.error");
    }
    onClear(): void {
        this.isUploading = false;
    }
    onProgress(): void {
        this.isUploading = true;
    }
    isRunning(): boolean { return false; }
}

export class FileUploadInfo {
    /**
     * 上传了的文件在服务器端的路径
     */
    uploadedFiles: string[];
   
    /**
     * Defines the UI of the component, possible values are "advanced" and "basic".
     */  
    mode = "basic";
    /**
     * 指定最大上传文件字节数，缺省为20M字节.
     */ 
    maxSize = 20000000;
    /** 
     * 允许上传的文件类型，如："image/*,text/*,".
     * 所有类型见：http://www.w3school.com.cn/media/media_mimeref.asp
     * 或直接规定扩展名，如：".csv,.sql".
     */ 
    allowedFileType: string = "";
    isDisabled = false;
    isMultipleMode = false;
    /**
     * 是否自动上传。
     * 是：选取文件就会自动上传；
     * 否：选取文件后，等到点击上传按钮才上传。
     */ 
    isAutoUpload = true;
    reset(): void{
        this.uploadedFiles = undefined;
    }
    constructor( allowedFileType?: string ) {
        if ( allowedFileType ) {
            this.allowedFileType = allowedFileType;
        }
    }
}