import { Component, Input } from '@angular/core';
import { Message } from 'primeng/components/common/api';
import {MessageService} from 'primeng/api';
import { Utils } from './utils';

@Component({
	selector: 'message-box',
	template: `<p-toast></p-toast>
	    <p-dialog [modal]="true" [header]="header" [draggable]="false" [closable]="false" [visible]="isRunning" [width]="150" 
            [height]="188" [minWidth]="148" [minHeight]="128" >
        <div style="margin-left: 60px" class="loading"></div>
	</p-dialog>`
})
export class MessageBoxComponent {
	@Input() isRunning: boolean;
	constructor(private messageService: MessageService) {}
	header = Utils.resolveLocalizedMessage('loading.data');
    static lifeTimeMap = {
        "success":5, "info":20, "warn":20, "error":60
     }
    showMessage(style: string, msg: string): void {
        let title = Utils.resolveLocalizedMessage("msg.type." + style);
        this.messageService.add({life:MessageBoxComponent.lifeTimeMap[style]*1000, severity: style, summary: title, detail: msg });
    }
    showMessages(style: string, messages: string[]): void {
        let msgs = [];
        for (let msg of messages) {
            let title = Utils.resolveLocalizedMessage("msg.type." + style);
            msgs.push({life:MessageBoxComponent.lifeTimeMap[style]*1000, severity: style, summary: title, detail: msg });
        }
        this.messageService.addAll(msgs);
    }
	clear() {
        this.messageService.clear();
    }
	getOffset(): any {
		//让消息框在屏幕可见区中间
		let clientWidth = document.documentElement.clientWidth;
		let clientHeight = document.documentElement.clientHeight;
		let top = document.documentElement.scrollTop ? document.documentElement.scrollTop : document.body.scrollTop;
		let left = document.documentElement.scrollLeft ? document.documentElement.scrollLeft : document.body.scrollLeft;
		let x = (clientWidth - 100) / 2 + left;
		let y = (clientHeight - 30) / 2 + top;
		//console.debug("x=" + x + "y=" + y + "document.body.scrollTop=" + top);
		return { left: x, top: y };
	}
}
